BlueThermalPrinterPlus class

Constructors

BlueThermalPrinterPlus()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isAvailable Future<bool?>
no setter
isConnected Future<bool?>
no setter
isOn Future<bool?>
no setter
onStateChanged Stream<int>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect(BluetoothDevice device) Future
disconnect() Future
getBondedDevices() Future<List<BluetoothDevice>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openSettings() Future<bool?>
print({required List<PrintItem> items, required PrinterProtocol protocol, int widthDots = 384}) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited